aldvmmaldvmm.check
runs validity checks of objects supplied to
aldvmm.
aldvmm.check(
formula,
data,
subset,
psi,
ncmp,
dist,
optim.method,
optim.control,
optim.grad,
init.method,
init.est,
init.lo,
init.hi,
se.fit,
model,
level,
na.action,
lcoef,
lcpar,
lcmp
)aldvmm.check returns warnings or stops the execution of
aldvmm if validity
checks fail.
an object of class "formula" with a symbolic
description of the model to be fitted. The model formula takes the form
y ~ x1 + x2 | x1 + x4, where the | delimiter separates the
model for expected values of normal distributions (left) and the
multinomial logit model of probabilities of component membership (right).
a data frame, list or environment (or object coercible to a data
frame by
as.data.frame)
including data on outcomes and explanatory variables in 'formula'.
an optional numeric vector of row indices of the subset of the model
matrix used in the estimation. 'subset' can be longer than the
number of rows in data and include repeated values for re-sampling
purposes.
a numeric vector of minimum and maximum possible utility values
smaller than or equal to 1 (e.g. c(-0.594, 0.883)). The potential
gap between the maximum value and 1 represents an area with zero density
in the value set from which utilities were obtained. The order of the
minimum and maximum limits in 'psi' does not matter.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
an optional character value of the distribution used in the
components. In this release, only the normal distribution is
available, and the default value is set to "normal".
an optional character value of one of the following
optimr
methods: "Nelder-Mead", "BFGS", "CG",
"L-BFGS-B", "nlminb", "Rcgmin", "Rvmmin" and
"hjn". The default method is "BFGS". The method
"L-BFGS-B" is used when lower and/or upper constraints are set
using 'init.lo' and 'init.hi'. The method "nlm"
cannot be used in the 'aldvmm' package.
an optional list of
optimr
control parameters.
an optional logical value indicating if an analytical
gradient should be used in
optimr
methods that can use this information. The default value is TRUE.
If 'optim.grad' is set to FALSE, a finite difference
approximation is used.
an optional character value indicating the method for
obtaining initial values. The following values are available:
"zero", "random", "constant" and "sann". The
default value is "zero".
an optional numeric vector of user-defined initial values.
User-defined initial values override the 'init.method' argument.
Initial values have to follow the same order as parameter estimates in the
return value 'coef'.
an optional numeric vector of user-defined lower limits for
constrained optimization. When 'init.lo' is not NULL, the
optimization method "L-BFGS-B" is used. Lower limits of parameters
have to follow the same order as parameter estimates in the return value
'coef'.
an optional numeric vector of user-defined upper limits for
constrained optimization. When 'init.hi' is not NULL, the
optimization method "L-BFGS-B" is used. Upper limits of parameters
have to follow the same order as parameter estimates in the return value
'coef'.
an optional logical value indicating whether standard errors
of fitted values are calculated. The default value is FALSE.
an optional logical value indicating whether the estimation
data frame is returned in the output object. The default value is
TRUE.
a numeric value of the significance level for confidence bands of fitted values. The default value is 0.95.
a character value passed to
argument 'na.action' of the function
model.frame
in the preparation of the model matrix. The default value is
"na.omit".
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
aldvmm.check
checks the validity of arguments of
aldvmm.