aldvmm.cv performs
a numerical approximation of the covariance matrix of parameter estimates.
aldvmm.cv(ll, par, X, y, dist, psi, ncmp, lcoef, lcpar, lcmp, optim.method)aldvmm.cv returns a list with the following objects.
hessiana numeric matrix with second-order partial
derivatives of the likelihood function 'll'.
cva
numeric matrix with covariances/variances of parameters in 'par'.
sea numeric vector of standard errors of parameters in
'par'.
za numeric vector of z-values of parameters
in 'par'.
pa numeric vector of p-values of parameter estimates.
uppera numeric vector of upper 95%
confidence limits of parameter estimates in 'par'.
lowera numeric vector of lower 95% confidence limits of
parameter estimates in 'par'.
a function returning the negative log-likelihood of the adjusted
limited dependent variable mixture model as a scalar result
(aldvmm.ll).
a named numeric vector of parameter values.
a list of design matrices returned by
aldvmm.mm.
'X' is of length 2 and includes a design matrix for the model of
component distributions and a design matrix for the model of probabilities
of group membership.
a numeric vector of observed outcomes from complete observations in
'data' supplied to
aldvmm.
an optional character value of the distribution used in the
components. In this release, only the normal distribution is
available, and the default value is set to "normal".
a numeric vector of minimum and maximum possible utility values
smaller than or equal to 1 (e.g. c(-0.594, 0.883)). The potential
gap between the maximum value and 1 represents an area with zero density
in the value set from which utilities were obtained. The order of the
minimum and maximum limits in 'psi' does not matter.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
an optional character value of one of the following
optimr
methods: "Nelder-Mead", "BFGS", "CG",
"L-BFGS-B", "nlminb", "Rcgmin", "Rvmmin" and
"hjn". The default method is "BFGS". The method
"L-BFGS-B" is used when lower and/or upper constraints are set
using 'init.lo' and 'init.hi'. The method "nlm"
cannot be used in the 'aldvmm' package.
aldvmm.cv
uses
hessian
to calculate the hessian matrix of the log-likelihood function supplied to
'll' at parameter values supplied to 'par'.