aldvmm.getnames
creates names of parameter vectors used in
aldvmm. The order of
the elements in 'lcoef' and 'lcpar' determines the order of
parameters and the structure of summary tables returned by
summary.aldvmm.
aldvmm.getnames(X, names, lcoef, lcpar, lcmp, ncmp)a character vector of names of parameter vectors used in
aldvmm.
a list of design matrices returned by
aldvmm.mm.
'X' is of length 2 and includes a design matrix for the model of
component distributions and a design matrix for the model of probabilities
of group membership.
a character vector of names of considered elements
(distributions "beta", multinomial logit "delta" or constant
distribution parameters, i.e. "lnsigma"). The elements in
'names' are combined with covariate names in 'X' and
component labels in 'lcmp' to create a vector of names of parameter
vectors.
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.