aldvmm.gr
calculates numerical gradients of the negative log-likelihood of the entire
estimation data with respect to parameter values in 'par'.
aldvmm.gr(par, X, y, psi, dist, ncmp, lcoef, lcmp, lcpar, optim.method)a named numeric vector of first derivatives of the negative
log-likelihood of the data with respect to parameters in 'par'.
a named numeric vector of parameter values.
a list of design matrices returned by
aldvmm.mm.
'X' is of length 2 and includes a design matrix for the model of
component distributions and a design matrix for the model of probabilities
of group membership.
a numeric vector of observed outcomes from complete observations in
'data' supplied to
aldvmm.
a numeric vector of minimum and maximum possible utility values
smaller than or equal to 1 (e.g. c(-0.594, 0.883)). The potential
gap between the maximum value and 1 represents an area with zero density
in the value set from which utilities were obtained. The order of the
minimum and maximum limits in 'psi' does not matter.
an optional character value of the distribution used in the
components. In this release, only the normal distribution is
available, and the default value is set to "normal".
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
an optional character value of one of the following
optimr
methods: "Nelder-Mead", "BFGS", "CG",
"L-BFGS-B", "nlminb", "Rcgmin", "Rvmmin" and
"hjn". The default method is "BFGS". The method
"L-BFGS-B" is used when lower and/or upper constraints are set
using 'init.lo' and 'init.hi'. The method "nlm"
cannot be used in the 'aldvmm' package.
aldvmm.gr
uses aldvmm.sc to
calculate analytical gradients of the negative log-likelihood.
If 'par' includes infinite values
aldvmm.gr returns a
gradient of zero.