aldvmm.init
creates initial values for the minimization of the negative log-likelihood
returned by
aldvmm.ll using
optimr.
aldvmm.init(
X,
y,
psi,
ncmp,
dist,
init.method,
init.est,
init.lo,
init.hi,
optim.method,
optim.control = list(),
optim.grad,
lcoef,
lcpar,
lcmp
)aldvmm.init
returns a list with the following objects.
esta numeric vector of initial values of parameters.
loa numeric vector of lower limits of parameters.
hia numeric vector of upper limits of parameters.
a list of design matrices returned by
aldvmm.mm.
'X' is of length 2 and includes a design matrix for the model of
component distributions and a design matrix for the model of probabilities
of group membership.
a numeric vector of observed outcomes from complete observations in
'data' supplied to
aldvmm.
a numeric vector of minimum and maximum possible utility values
smaller than or equal to 1 (e.g. c(-0.594, 0.883)). The potential
gap between the maximum value and 1 represents an area with zero density
in the value set from which utilities were obtained. The order of the
minimum and maximum limits in 'psi' does not matter.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
an optional character value of the distribution used in the
components. In this release, only the normal distribution is
available, and the default value is set to "normal".
an optional character value indicating the method for
obtaining initial values. The following values are available:
"zero", "random", "constant" and "sann". The
default value is "zero".
an optional numeric vector of user-defined initial values.
User-defined initial values override the 'init.method' argument.
Initial values have to follow the same order as parameter estimates in the
return value 'coef'.
an optional numeric vector of user-defined lower limits for
constrained optimization. When 'init.lo' is not NULL, the
optimization method "L-BFGS-B" is used. Lower limits of parameters
have to follow the same order as parameter estimates in the return value
'coef'.
an optional numeric vector of user-defined upper limits for
constrained optimization. When 'init.hi' is not NULL, the
optimization method "L-BFGS-B" is used. Upper limits of parameters
have to follow the same order as parameter estimates in the return value
'coef'.
an optional character value of one of the following
optimr
methods: "Nelder-Mead", "BFGS", "CG",
"L-BFGS-B", "nlminb", "Rcgmin", "Rvmmin" and
"hjn". The default method is "BFGS". The method
"L-BFGS-B" is used when lower and/or upper constraints are set
using 'init.lo' and 'init.hi'. The method "nlm"
cannot be used in the 'aldvmm' package.
an optional list of
optimr
control parameters.
an optional logical value indicating if an analytical
gradient should be used in
optimr
methods that can use this information. The default value is TRUE.
If 'optim.grad' is set to FALSE, a finite difference
approximation is used.
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
'init.method' accepts four methods for generating initial
values: "zero", "random", "constant", "sann".
The method "zero" sets initial values of all parameters to 0. The
method "random" draws random starting values from a standard normal
distribution. The method "constant" estimates a constant-only
model and uses estimates as initial values for intercepts and constant
distribution parameters and 0 for all other parameters. The method
"sann" estimates the full model using the simulated annealing
optimization method and uses all parameter estimates as initial values.
When user-specified initial values are supplied in 'init.est', the
argument 'init.method' is ignored.
By default, aldvmm
performs unconstrained optimization with upper and lower limits at
-Inf and Inf. When user-defined lower and upper limits are
supplied to 'init.lo' and/or 'init-hi', these default limits
are replaced with the user-specified values, and the method
"L-BFGS-B" is used for box-constrained optimization instead of the
user defined 'optim.method'. It is possible to only set either
maximum or minimum limits. When initial values supplied to
'init.est' or from default methods lie outside the limits, the
in-feasible values will be set to the limits using the function
bmchk.