aldvmm.pred makes
predictions of observations in design matrices in 'X' using parameter
estimates returned by
aldvmm.
aldvmm.pred(par, X, y = NULL, psi, ncmp, dist, lcoef, lcpar, lcmp)a list of of predicted outcomes including the following elements.
ya numeric vector of observed outcomes in 'data'.
yhata numeric vector of fitted values.
resa numeric vector of residuals.
proba numeric matrix of expected
probabilities of group membership per individual in 'data'.
a named numeric vector of parameter values.
a list of design matrices returned by
aldvmm.mm.
'X' is of length 2 and includes a design matrix for the model of
component distributions and a design matrix for the model of probabilities
of group membership.
a numeric vector of observed outcomes from complete observations in
'data' supplied to
aldvmm.
a numeric vector of minimum and maximum possible utility values
smaller than or equal to 1 (e.g. c(-0.594, 0.883)). The potential
gap between the maximum value and 1 represents an area with zero density
in the value set from which utilities were obtained. The order of the
minimum and maximum limits in 'psi' does not matter.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
an optional character value of the distribution used in the
components. In this release, only the normal distribution is
available, and the default value is set to "normal".
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
a character vector with the labels of objects including
constant parameters of component distributions (e.g. the standard
deviation of the normal distribution). The length of 'lcpar'
depends on the distribution supplied to 'dist'.
a character value representing a stub (default "Comp")
for labeling objects including regression coefficients in different
components (e.g. "Comp1", "Comp2", ...). This label is also used in
summary tables returned by
summary.aldvmm.
aldvmm.pred
calculates expected values for observations in design matrices in 'X'
using the expected value function published in Hernandez Alava and Wailoo
(2015). Constant distribution parameters that need to be non-negative (i.e.
standard deviations of normal distributions) enter the expected value
function as log-transformed values.