Learn R Programming

aldvmm (version 0.9.0)

aldvmm.sum: Creating Summary Table

Description

aldvmm.sum creates a summary table of regression results.

Usage

aldvmm.sum(object, digits = max(3L, getOption("digits") - 3L), level = 0.95)

Value

a data.frame object with a summary table of regression results.

Arguments

object

an aldvmm model fit object of class "aldvmm".

digits

a numeric value of the number of digits in the reporting table.

level

a numeric value of the confidence level.