aldvmm.tm creates
a list of up to three "terms" objects, one of the model of component distributions
("beta"), one of the model of probabilities of component
membership ("delta") and one for the full model ("full").
aldvmm.tm(mf, Formula, ncmp, lcoef)a named list of objects of class "terms".
betaa "terms" object for the model of component distributions.
deltaa "terms" object of the multinomial logit model of probabilities of component membership.
fulla "terms" object of the full model.
a data frame created by
model.frame
including the variables used in 'formula' supplied to
aldvmm plus
additional attributes derived from 'formula'.
an object of class "Formula" created by
Formula
based on the 'formula' supplied to
aldvmm.
a numeric value of the number of components that are mixed. The
default value is 2. A value of 1 represents a tobit model with a gap
between 1 and the maximum value in 'psi'.
a character vector of length 2 with labels of objects including
regression coefficients of component distributions (default "beta")
and coefficients of probabilities of component membership (default
"delta").
aldvmm.tm
uses
terms
to create "terms" objects based on a "Formula" object
created by
Formula
and a model frame created by
model.frame.
The "terms" object for probabilities of group membership is only created if
more than one components are specified in 'ncmp'.