Learn R Programming

aldvmm (version 0.9.0)

coef.aldvmm: Extract Coefficients of Adjusted Limited Dependent Variable Mixture Model Fits

Description

The method coef.aldvmm for the generic function coef extracts the vector of coefficients from an object of class "aldvmm".

Usage

# S3 method for aldvmm
coef(object, ...)

Value

a named numeric vector of parameter estimates.

Arguments

object

an object inheriting from class "aldvmm".

...

further arguments passed to or from other methods.