The method estfun.aldvmm for the generic function
estfun calculates the gradient of the aldvmm
log-likelihood using with respect to parameter values for each observation
aldvmm.sc.
# S3 method for aldvmm
estfun(x, ...)a numeric matrix of gradients with one row per observation and one column per parameter.
an object inheriting from class "aldvmm".
further arguments passed to or from other methods.