Learn R Programming

aldvmm (version 0.9.0)

model.matrix.aldvmm: Extract Adjusted Limited Dependent Variable Mixture Model Model Matrices

Description

The method model.matrix.aldvmm for the generic function model.matrix extracts a list of model matrices from an object of class "aldvmm" using the function aldvmm.mm.

Usage

# S3 method for aldvmm
model.matrix(object, ...)

Value

a named list of numeric matrices.

beta

a numeric design matrix for the model of component distributions.

delta

a numeric design matrix of the multinomial logit model of probabilities of component membership.

Arguments

object

an object inheriting from class "aldvmm".

...

further arguments passed to or from other methods.