nobs.aldvmm: Extract Adjusted Limited Dependent Variable Mixture Model Number of Observations
Description
The method nobs.aldvmm for the generic function
nobs extracts the
number of observations from an object of class "aldvmm".
Usage
# S3 method for aldvmm
nobs(object, ...)
Value
a scalar of the number of complete
observations.
Arguments
- object
an object inheriting from class "aldvmm".
- ...
further arguments passed to or from other methods.