The method predict.aldvmm for the generic function
predict calls
aldvmm.pred and aldvmm.sefit to
predict outcomes and their standard errors in new data.
# S3 method for aldvmm
predict(
object,
newdata = NULL,
se.fit = FALSE,
type = "pred",
level = 0.95,
...
)a named list of numeric vectors of predicted outcomes, standard errors and confidence or prediction intervals.
an object inheriting from class 'aldvmm'.
a data frame, list or environment (or object coercible to a
data frame by
as.data.frame) including explanatory variables for
prediction.
an optional logical value indicating whether standard errors
of fitted values are calculated. The default value is FALSE.
a character value of either 'fit' or 'pred' indicating whether the standard error of the fit ('fit') or the standard error of predictions in new data ('pred') are calculated.
a numeric value of the significance level for confidence bands of fitted values. The default value is 0.95.
further arguments passed to or from other methods.