Learn R Programming

aldvmm (version 0.9.0)

print.aldvmm: Print Adjusted Limited Dependent Variable Mixture Model Fits

Description

The method print.aldvmm for the generic function print prints a summary of an object of class "aldvmm".

Usage

# S3 method for aldvmm
print(x, digits = max(3L, getOption("digits") - 3L), ...)

Arguments

x

an object inheriting from class "aldvmm".

digits

an integer value of the number of digits in the printed output.

...

further arguments passed to or from other methods.