Learn R Programming

aldvmm (version 0.9.0)

print.summary.aldvmm: Printing Adjusted Limited Dependent Variable Mixture Model Summaries

Description

The method print.summary.aldvmm for the generic function print prints a summary of an object of class "summary.aldvmm".

Usage

# S3 method for summary.aldvmm
print(x, digits = max(3L, getOption("digits") - 3L), ...)

Arguments

x

an object inheriting from class 'summary.aldvmm'.

digits

an integer value of the number of digits in the output table.

...

further arguments passed to or from other methods.