The method summary.aldvmm for the generic function
summary creates
an object of class "summary.aldvmm" including key results from an object of
class "aldvmm".
# S3 method for aldvmm
summary(object, digits = max(3L, getOption("digits") - 3L), level = 0.95, ...)summary.aldvmm returns an object of class "summary.aldvmm"
including the following elements.
calla character value including the model call captured by
match.call.
summarya data frame generated by
aldvmm.sum
including a formatted summary of model results for printing.
termsa list of objects of class
terms.
contrastsa nested list of character values showing contrasts of factors used in models of component means ("beta") and probabilities of component membership ("delta").
coefa numeric vector of parameter estimates.
cova numeric matrix object with covariances of parameters.
na scalar representing the number of complete observations with no missing values that were used in the estimation.
df.residualan integer value of the residual degrees of freedom.
df.nullan integer value of the residual degrees of freedom of a null model including intercepts and standard errors.
iteran integer value of the number of iterations used in optimization.
lla numeric value of the negative log-likelihood \(-ll\).
aica numeric value of the Akaike information criterion \(AIC = 2n_{par} - 2ll\).
bica numeric value of the Bayesian information criterion \(BIC = n_{par}*log(n_{obs}) - 2ll\).
ka numeric value of the number of components.
lcoefa character vector of labels for objects including
results on distributions (default "beta") and the probabilities of
component membership (default "delta").
lcpara
character vector of labels for objects including constant distribution
parameters (default "sigma" for dist = "normal").
lcmpa character value of the label for objects including results on different components (default "Comp")
lvara
list including 2 character vectors of covariate names for model parameters
of distributions ("beta") and the multinomial logit
("delta").
an object inheriting from class 'aldvmm'.
an integer value of the number of digits in the output table.
a numeric value of the confidence interval between 0 and 1.
further arguments passed to or from other methods.