Learn R Programming

aldvmm (version 0.9.0)

vcov.aldvmm: Extract Adjusted Limited Dependent Variable Mixture Model Covariance Matrix

Description

The method vcov.aldvmm for the generic function vcov returns the covariance matrix from an object of class "aldvmm".

Usage

# S3 method for aldvmm
vcov(object, ...)

Value

a numeric matrix.

Arguments

object

an object inheriting from class "aldvmm".

...

further arguments passed to or from other methods.