The method
model.matrix.aldvmm for the generic function model.matrix extracts a list of model matrices from an object
of class "aldvmm" using the function
aldvmm.mm.
# S3 method for aldvmm
model.matrix(object, ...)a named list of numeric matrices.
betaa numeric design matrix for the model of component distributions.
deltaa numeric design matrix of the multinomial logit model of probabilities of component membership.
an object inheriting from class "aldvmm".
further arguments passed to or from other methods.